@@ -43,7 +43,7 @@ class SyncReplConsumer(ReconnectLDAPObject,SyncreplConsumer):
         # We need this for later internal use
         self.__presentUUIDs = dict()
 
-    def __del__(self):
+    def close_db(self):
             # Close the data store properly to avoid corruption
             self.__data.close()
 
@@ -109,6 +109,7 @@ def commenceShutdown(signum, stack):
 
     # Tear down the server connection
     if( ldap_connection ):
+            ldap_connection.close_db()
             del ldap_connection
 
     # Shutdown
@@ -124,11 +125,18 @@ try:
   ldap_url = ldapurl.LDAPUrl(sys.argv[1])
   database_path = sys.argv[2]
 except IndexError,e:
-  print 'Usage: syncrepl-client.py <LDAP URL> <pathname of database>'
-  sys.exit(1)
+    print 'Usage:'
+    print sys.argv[0], '<LDAP URL> <pathname of database>'
+    print sys.argv[0], '\'ldap://127.0.0.1/cn=users,dc=test'\
+                       '?*'\
+                       '?sub'\
+                       '?(objectClass=*)'\
+                       '?bindname=uid=admin%2ccn=users%2cdc=test,'\
+                       'X-BINDPW=password\' db.shelve'
+    sys.exit(1)
 except ValueError,e:
-  print 'Error parsing command-line arguments:',str(e)
-  sys.exit(1)
+    print 'Error parsing command-line arguments:',str(e)
+    sys.exit(1)
 
 while watcher_running:
     print 'Connecting to LDAP server now...'
@@ -152,6 +160,7 @@ while watcher_running:
       ldap_url.dn or '',
       ldap_url.scope or ldap.SCOPE_SUBTREE,
       mode = 'refreshAndPersist',
+      attrlist=ldap_url.attrs,
       filterstr = ldap_url.filterstr or '(objectClass=*)'
     )
 
