@@ -3,12 +3,12 @@ ldap - base module
 
 See http://www.python-ldap.org/ for details.
 
-$Id: __init__.py,v 1.88 2013/11/23 14:09:59 stroeder Exp $
+$Id: __init__.py,v 1.93 2014/07/25 17:08:56 stroeder Exp $
 """
 
 # This is also the overall release version number
 
-__version__ = '2.4.14'
+__version__ = '2.4.16'
 
 import sys
 
@@ -82,7 +82,9 @@ class LDAPLock:
 # Create module-wide lock for serializing all calls into underlying LDAP lib
 _ldap_module_lock = LDAPLock(desc='Module wide')
 
-from functions import open,initialize,init,get_option,set_option
+from functions import open,initialize,init,get_option,set_option,escape_str
+
+from ldapobject import NO_UNIQUE_ENTRY
 
 from ldap.dn import explode_dn,explode_rdn,str2dn,dn2str
 del str2dn
